#!/usr/bin/env node
'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

var _loader = require('./loader');

var _loader2 = _interopRequireDefault(_loader);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _yargs = require('yargs');

var _yargs2 = _interopRequireDefault(_yargs);

var _jsYaml = require('js-yaml');

var _jsYaml2 = _interopRequireDefault(_jsYaml);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _yargs$usage$option$o = _yargs2.default.usage('Usage: $0 [files] [options]').option('5', {
  alias: 'es5',
  describe: 'Use babel presets es2015 and react',
  boolean: true,
  default: false
}).option('0', {
  alias: 'stdout',
  describe: 'Print output to stdout',
  boolean: true,
  default: 'false'
})
// svgo options
.option('svgo', {
  describe: 'Path to YAML or JS or JSON config file for SVGO',
  nargs: 1
}).array('svgo.plugins').option('svgo.floatPrecision', { number: true, default: 3 }).boolean('svgo.multipass').boolean('svgo.full').boolean('svgo.js2svg.pretty').option('svgo.js2svg.useShortTags', { default: true, boolean: true }).demand(1).version(require('../package.json').version).help('h').alias('h', 'help');

var argv = _yargs$usage$option$o.argv;


function makeFilename(filename) {
  return filename + '.react.js';
}

function handlePath(configFile) {
  switch (_path2.default.extname(configFile)) {
    case '.yaml':
      return _jsYaml2.default.safeLoad(_fs2.default.readFileSync(configFile));
    case '.json':
    case '.js':
      return require(_path2.default.join(process.cwd(), configFile));
    default:
      throw new Error('Unsupported config file format.');
  }
}

var svgoOpts = void 0;

switch (_typeof(argv.svgo)) {
  case 'string':
    svgoOpts = handlePath(argv.svgo);
    break;
  case 'object':
    svgoOpts = argv.svgo;
    if (Array.isArray(svgoOpts.plugins)) break;

    // when there is only one element
    if (typeof svgoOpts.plugins === 'string') {
      svgoOpts.plugins = [svgoOpts.plugins];
      break;
    }

    // when there are many and is an object
    if (svgoOpts.plugins) {
      svgoOpts.plugins = Object.keys(svgoOpts.plugins).map(function (key) {
        var _ref;

        if (svgoOpts.plugins[key] === true) return key;
        return _ref = {}, _ref[key] = svgoOpts.plugins[key], _ref;
      });
    }
    break;
}

argv._.map(function (file) {
  var source = _fs2.default.readFileSync(file);

  var query = void 0;
  try {
    // serializable check
    query = '?' + JSON.stringify({
      es5: argv.es5,
      svgo: svgoOpts
    });
  } catch (e) {
    /* eslint-disable no-console */
    console.error('The options passed are not serializable.');
    /* eslint-enable */
    process.exit(1);
  }
  var loaderContext = {
    query: query,
    cacheable: function cacheable() {},
    addDependency: function addDependency() {},
    async: function async() {
      return function (err, result) {
        /* eslint-disable no-console */
        if (err) return console.error("ERROR ERROR ERROR", file, err.stack);
        if (argv['0']) console.log(result);
        /* eslint-enable */
        else _fs2.default.writeFileSync(makeFilename(file), result);
      };
    }
  };
  _loader2.default.apply(loaderContext, [source]);
});